Index: trunk/psModules/src/config/pmConfig.h
===================================================================
--- trunk/psModules/src/config/pmConfig.h	(revision 15385)
+++ trunk/psModules/src/config/pmConfig.h	(revision 16611)
@@ -5,6 +5,6 @@
  *  @author Eugene Magnier, IfA
  *
- *  @version $Revision: 1.32 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2007-10-26 02:41:15 $
+ *  @version $Revision: 1.33 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2008-02-22 20:20:38 $
  *  Copyright 2005-2006 Institute for Astronomy, University of Hawaii
  */
@@ -25,5 +25,5 @@
 typedef enum {
     PM_RECIPE_SOURCE_NONE        = 0x00, ///< None yet
-    PM_RECIPE_SOURCE_SITE        = 0x01, ///< Site configuration
+    PM_RECIPE_SOURCE_SYSTEM      = 0x01, ///< System configuration
     PM_RECIPE_SOURCE_CAMERA      = 0x02, ///< Camera configuration
     PM_RECIPE_SOURCE_CL          = 0x04, ///< Command-line
@@ -34,8 +34,11 @@
 /// Configuration information
 ///
 /// This structure stores the configuration information: the site, camera and recipe configuration, the
 /// command-line arguments, the pmFPAfiles used, and the database handle.
 typedef struct {
-    psMetadata *site;                   ///< Site configuration
+    psMetadata *user;                 	///< User configuration
+    psMetadata *site;                 	///< Site configuration
+    psMetadata *system;               	///< System configuration
+    psMetadata *complete;               ///< Full merged configuration
     psMetadata *camera;                 ///< Camera specification
     psString cameraName;                ///< Camera name
@@ -68,10 +71,10 @@
 /// Read configuration information from the command line.
 ///
 /// pmConfigRead loads the site configuration (the file name is specified by "-site SITE_FILE" on the
 /// command-line, the PS_SITE environment variable, or it is $HOME/.ipprc).  The configuration search path is
 /// set. The camera configuration is loaded if it is specified on the command line ("-camera
 /// CAMERA_FILE"). Recipes specified on the command line ("-recipe RECIPE_NAME RECIPE_SOURCE") are also
 /// loaded.  These command-line arguments are removed from from the command-line, to simplify parsing.  The
 /// psLib log, trace and time setups are also performed if specified in the site configuration.
 pmConfig *pmConfigRead(int *argc,       ///< Number of command-line arguments
                        char **argv, ///< Array of command-line arguments
@@ -166,5 +169,5 @@
 /// Get the file rule of interest
 ///
 /// Look up the name of the set of file rules to use, get that set from the site configuration, and return the
 /// appropriate rule from the set.
 psMetadata *pmConfigFileRule(const pmConfig *config, ///< Configuration
@@ -34,8 +34,11 @@
 /// Configuration information
 ///
-/// This structure stores the configuration information: the site, camera and recipe configuration, the
+/// This structure stores the configuration information: user, site, system, camera and recipe configuration, the
 /// command-line arguments, the pmFPAfiles used, and the database handle.
 typedef struct {
@@ -68,10 +71,10 @@
 /// Read configuration information from the command line.
 ///
-/// pmConfigRead loads the site configuration (the file name is specified by "-site SITE_FILE" on the
-/// command-line, the PS_SITE environment variable, or it is $HOME/.ipprc).  The configuration search path is
+/// pmConfigRead loads the user configuration (the file name is specified by "-ipprc FILE" on the
+/// command-line, the IPPRC environment variable, or it is $HOME/.ipprc).  The configuration search path is
 /// set. The camera configuration is loaded if it is specified on the command line ("-camera
 /// CAMERA_FILE"). Recipes specified on the command line ("-recipe RECIPE_NAME RECIPE_SOURCE") are also
@@ -68,10 +71,10 @@
 /// CAMERA_FILE"). Recipes specified on the command line ("-recipe RECIPE_NAME RECIPE_SOURCE") are also
 /// loaded.  These command-line arguments are removed from from the command-line, to simplify parsing.  The
-/// psLib log, trace and time setups are also performed if specified in the site configuration.
+/// psLib log, trace and time setups are also performed if specified in the user configuration.
 pmConfig *pmConfigRead(int *argc,       ///< Number of command-line arguments
                        char **argv, ///< Array of command-line arguments
@@ -166,5 +169,5 @@
 /// Get the file rule of interest
 ///
-/// Look up the name of the set of file rules to use, get that set from the site configuration, and return the
+/// Look up the name of the set of file rules to use, get that set from the system configuration, and return the
 /// appropriate rule from the set.
 psMetadata *pmConfigFileRule(const pmConfig *config, ///< Configuration
